<?php
class Hispanicize_Wire_Feed_Cached_Repository extends Hispanicize_Wire_Feed_Repository
{
    public function getFeeds($url) {
        $json = $this->get($url);
        if ($this->shouldRemoveCache($url)) {
            $this->deleteCacheFolder();
        }
        if (! $json || ! $this->isValidCache($url)) {
            $json = parent::getFeeds($url);
            $this->put($url, $json);
        }
        return $json;
    }

    private function deleteCacheFolder() {
        $cacheDirectory = $this->getCacheDirectory();
        if (is_dir($cacheDirectory)) {
            exec('rm -r ' . $cacheDirectory);
        }
    }

    private function get($url) {
        $json = FALSE;
        $filePath = $this->getFilePath($url);
        if (! is_file($filePath)) {
            return FALSE;
        }
        try {
            $content = file_get_contents($filePath);
            if ($content !== FALSE) {
                $json = $content;
            }
        } catch(Exception $ex) {
            return FALSE;
        }
        return $json;
    }

    private function put($url, $json) {
        if (empty($json) || $json == FALSE) {
            return FALSE;
        }
        $cacheDirectory = $this->getCacheDirectory();
        $this->makeDirectory($cacheDirectory);
        if (! is_dir($cacheDirectory)) {
            return FALSE;
        }
        $filePath = $this->getFilePath($url);
        try {
            file_put_contents($filePath, $json);
            clearstatcache();
        } catch(Exception $ex) {
            return FALSE;
        }
    }

    private function makeDirectory($path) {
        if (is_dir($path)) {
            return FALSE;
        }
        try {
            $oldmask = umask(0);
            mkdir($path);
            umask($oldmask);
        } catch(Exception $ex) {
            return FALSE;
        }
    }

    private function getFilePath($url) {
        $apiUrl = HW_API_URL . "?";
        $fileName = str_replace($apiUrl, "", strtolower($url));
		$fileName = md5($fileName);
        $filePath = $this->getCacheDirectory() . DIRECTORY_SEPARATOR . $fileName . ".json";
        return $filePath;
    }

    private function getCacheDirectory() {
        return realpath(dirname(__FILE__)) . DIRECTORY_SEPARATOR . "cache";
    }

    private function getLogDirectory() {
        return realpath(dirname(__FILE__)) . DIRECTORY_SEPARATOR . "logs";
    }

    private function isValidCache($url) {
        $filePath = $this->getFilePath($url);
        if (! is_file($filePath)) {
            return FALSE;
        }
        $lastModifiedTime = "";
        try {
            $lastModifiedTimestamp = filemtime($filePath);
            if (! $lastModifiedTimestamp) {
                return FALSE;
            }
        } catch(Exception $ex) {
            return FALSE;
        }
        $hours = $this->getElapsedHoursWorkaround($lastModifiedTimestamp);        
        $maxHours = (int) HW_CACHE_HOURS;
        $valid = $hours <= $maxHours;
        return $valid;
    }

    private function shouldRemoveCache($url) {
        $filePath = $this->getFilePath($url);
        if (!is_file($filePath)) {
            return FALSE;
        }
        $lastModifiedTime = "";
        try {
            $lastModifiedTimestamp = filemtime($filePath);
            if (! $lastModifiedTimestamp) {
                return FALSE;
            }
        } catch(Exception $ex) {
            return FALSE;
        }
        $hours = $this->getElapsedHoursWorkaround($lastModifiedTimestamp);        
        $maxHours = (int) HW_CACHE_HOURS;
        $remove = $hours > $maxHours;
        if ($remove) {
            $this->writeLog("Cache is being removed - " . $hours . " ** " . $maxHours);
        }
        return $remove;
    }

    private function getElapsedHoursWorkaround($lastModifiedTimestamp) {
        $secondsInOneHour = 3600;
        $difference = time() - $lastModifiedTimestamp;
        $hours = (int) round($difference / $secondsInOneHour);
        return $hours;
    }

    private function getElapsedHours($lastModifiedTimestamp) {
        $currentDate = new DateTime();
        $modifiedDate = new DateTime();
        $modifiedDate->setTimestamp($lastModifiedTimestamp);
        $difference = $currentDate->diff($modifiedDate);
        $hours = (int) $difference->format('%h');
        $hours = $hours + ($difference->days * 24);
        return $hours;
    }

    private function writeLog($text) {
        try {
            $logDirectory = $this->getLogDirectory();
            $this->makeDirectory($logDirectory);
            $date = str_replace("/","-",gmdate("Y/m"));
            $filename = $logDirectory . "/log_" . $date . ".log";
            $ddf = fopen($filename,'a');
            $date_time = gmdate("Y/m/d H:i:s");
            fwrite($ddf,"[" . $date_time ."] " . $text . "\n");
            fclose($ddf);
        } catch(\Exception $e) {
        }
    }
}
