<?php
/**
 * Plugin Name: Hispanicize Wire News
 * Plugin URI: https://www.hispanicizewire.com/placements
 * Description: List all news from hispanicizewire.com in html format.
 * Version: 3.5.2
 * Author: Hispanic Market Advisors
 * Author URI: https://www.hispanicmarketadvisors.com/plug-ins
 * Requires at least: 4.5
 * Tested up to: 4.7.3
 *
 */
 
if (!defined('ABSPATH')) exit;

// Include plugin class files
require_once('hispanicize-wire-settings.php');
require_once('hispanicize-wire-feed.php');
require_once('hispanicize-wire-feed-repository.php');
require_once('hispanicize-wire-feed-cached-repository.php');

/**
 * Returns the main instance of Hispanicize_Wire_News to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return object Hispanicize_Wire_News
 */
function Hispanicize_Wire_News() {
    $instance = Hispanicize_Wire_News_Plugin::instance(__FILE__, '3.5.1');
    if (is_null($instance->settings)) {
        $instance->settings = Hispanicize_Wire_Settings::instance($instance);
    }
    return $instance;
}

Hispanicize_Wire_News();

class Hispanicize_Wire_News_Plugin {

    /**
     * The single instance of Hispanicize_Wire_Client_Plugin.
     * @var     object
     * @access  private
     * @since   1.0.0
     */
    private static $_instance = null;

    /**
     * Settings class object
     * @var     object
     * @access  public
     * @since   1.0.0
     */
    public $settings = null;

    /**
     * The version number.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
	public $_version;

    /**
     * The token.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $_token;
	 
    /**
     * Hispanicize Wire URL
     * @var string
     * @access public
     */
    public $hispanicizewire_url = HW_API_URL;

    /**
     * Hispanicize Wire Domain
     * @var string
     * @access public
     */
	public $hispanicize_domain = HW_DOMAIN;

    /**
     * The title
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $hispanicize_title = '';
	
    /**
     * Constructor function.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function __construct($file = '', $version = '3.2.0') {
	
		$this->_version = $version;
        $this->_token = 'hispanicize_wire_news';	
        $this->file = $file;
        $this->dir = dirname($this->file);
        $this->assets_dir = trailingslashit($this->dir) . 'assets';
        $this->assets_url = esc_url(trailingslashit(plugins_url('/assets/', $this->file)));

        // Load frontend JS & CSS
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'), 10);
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'), 10);

        // Load admin JS & CSS
        add_action('admin_enqueue_scripts', array($this, 'admin_enqueue_scripts'), 10, 1);
        add_action('admin_enqueue_scripts', array($this, 'admin_enqueue_styles'), 10, 1);
		
		add_shortcode('hispanicize-wire-news', array($this, 'Hispanicize_Wire_Display'));
		
		$index_req = 0;
		if (!empty($_GET['i']))  { $index_req = $_GET['i']; } // i = index of any post.. to see any specific post entry		
		if ($index_req != 0) {
			add_filter( 'wp_title', array($this, 'get_hispanicize_title'), 100, 1);	
		}
	}
	
    /**
     * List all Hispanicize Wire News.
     * @return string
     */
    public function Hispanicize_Wire_Display($atts) {
		
		
        $atts = shortcode_atts(array(
			'logo' => 'No',
			'title' => 'Hispanicize Wire News',
			'language' => 'en',
			'category' => '',
			'thumbnail' => 'Yes',
			'num_posts' => 3,
			'post_date' => 'Yes',
			'widget_size' => '',
			'widget_width' => '',
			'widget_height' => '',
			'widget_color' => '',
			'show_description' => 'Yes',
			'font' => 'inherit',
			'width' => 50,
			'mainpage' => '/hispanicize-wire-news',	
			'viewmore' => 'Yes',
			'pagination' => 'No',
			'target' => 'sidebar',
			'powered_by_title' => 'Feed Powered by Hispanic Market Advisors&#174;'
        ), $atts, 'hispanicize-wire-news');
        
		// Default value variables
		$index_req = 0;
		$post_index = 0;
		$location = '';
		$paged = 1;

		$logo = $atts['logo'];
		$title = $atts['title'];
		$language = $atts['language'];
		$category = $atts['category'];
		$thumbnail = 64;
		$has_thumbnail = (isset($atts['thumbnail']) && strtolower($atts['thumbnail']) != 'no') ? 'Yes' : 'No';
		$num_posts = $atts['num_posts'];
		$post_date = $atts['post_date'];
		$widget_size = $atts['widget_size'];
		$widget_width = $atts['widget_width'];
		$widget_height = $atts['widget_height'];
		$widget_color = $atts['widget_color']; 
		$show_description = $atts['show_description'];
		$font = $atts['font'];
		$mainpage = $atts['mainpage'];
		$viewmore = $atts['viewmore'];
		$pagination = $atts['pagination'];
		$target = $atts['target'];
		$powered_by_title = $atts['powered_by_title'];
		$return_value = '';
		$link_post = '';
		
		if (!empty($_GET['i']))  { $index_req = $_GET['i']; } // i = index of any post.. to see any specific post entry		
		if (!empty($_GET['pg'])) { $paged = $_GET['pg']; }	 // for pagination, pg contains the page to be seen
		if (!empty($_GET['l'])) { $link_post = $_GET['l']; }	 // for pagination, pg contains the page to be seen
		
		if ($target == 'sidebar') { $viewmore = 'Yes'; $pagination = 'No'; } else { $viewmore = 'No'; $pagination = 'Yes'; }
		if ($has_thumbnail == 'Yes') { $thumbnail = 64; } else { $thumbnail = 0; }
		
		$urlclient = $mainpage;
		$urlclient = str_ireplace("https://", "", $urlclient);
		$urlclient = str_ireplace("http://", "", $urlclient);
		$urlclient = str_ireplace("hispanicize-wire-news", "", $urlclient);
		$urlclient = str_ireplace("www.", "", $urlclient);
		$urlclient = str_ireplace("/", "", $urlclient);
			
		$queryString = '?paged=' . $paged . '&lang=' . $language . '&cat=' . $category . '&thumb_width=' . $thumbnail . '&urlclient=' . $urlclient;
        $queryString .= '&post=' . $link_post . '&num_posts=' . $num_posts . '&post_date=' . $post_date . "&show_desc=" . $show_description;
		$hispanicize_wire_feed = new Hispanicize_Wire_Feed($this->hispanicizewire_url . $queryString);
		
		// Building the page to be displayed
		
		$color_light = $this->get_light_color();
		$color_dark = $this->get_dark_color(); 
				
		$widget_style_size = '';
		if ($widget_size === '') {
			$widget_style_size = '';
		} elseif ($widget_size === 'custom') { // custom
			$widget_style_size = 'width:' . $widget_width . 'px;height:' . $widget_height . 'px;overflow:auto;';
		} elseif ($widget_size == '300x300') {
			$widget_style_size = 'width:300px;height:300px;overflow:auto;';
		} elseif ($widget_size == '300x550') {
			$widget_style_size = 'width:300px;height:550px;overflow:auto;';
		} elseif ($widget_size == '550x300') {
			$widget_style_size = 'width:550px;height:300px;overflow:auto;';
		}

		$widget_style = '';
		$widget_style_color = '';
		$title_color = 'color:inherit';
		
		if ($target == 'sidebar') { // only apply for Widget
			if ($widget_color === 'inherit') {
				$widget_style_color = '';
			} elseif ($widget_color === 'light') {
				$widget_style_color = 'background-color:' . $color_light . ';color:#000;';
			} elseif ($widget_color === 'dark') {
				$widget_style_color = 'background-color:' . $color_dark . ';color:#fff;';
				$title_color = 'color:#fff;';
			}
		
			if ( ($widget_style_size !== '') || ($widget_style_color !== '') ) {
				$widget_style = ' style="' . $widget_style_size . $widget_style_color . '"; ';
			}
		}

		$return_value .= '<div class="hw-widget-' . $target . '" ' . $widget_style . '>';
		
		// ******************* if we must display the list of post entries *************************************
		if ( $link_post == '' || $viewmore == "Yes" ) : 

			if ($title !== "") :
				if ($logo == "Yes") :
					if ( ($target == 'sidebar') && ($widget_color !== '') ) {
						$return_value .= '<div class="hw-post-title-logo" style="background:none;font-family:' . $font . ';"><img src="https://www.hispanicizewire.com/placements/logo-thumb.jpg" width="54px" />' . $title . '</div>';
					} else {
						$return_value .= '<div class="hw-post-title-logo" style="font-family:' . $font . ';"><img src="https://www.hispanicizewire.com/placements/logo-thumb.png" width="54px" />' . $title . '</div>';
					}
				else :
					$return_value .= '<div class="hw-post-title" style="font-family:' . $font . ';">' . $title . '</div>';
				endif;
			else :
				if ($logo == "Yes") :
					$return_value .= '<div class="hw-post-title-logo"><img src="https://www.hispanicizewire.com/placements/logo-thumb.png" width="54px" /></div>';
				endif;
			endif;

			$return_value .= '<div class="hw-clear-both"></div>';
			$return_value .= '<div class="hw-widget-body">';
			
			foreach($hispanicize_wire_feed->posts as $post) :
				$post_index++;
				if ($post_index <= $num_posts)	:
					$return_value .= '<div class="hw-post-entry">';
					if ($show_description == "Yes") : 
						$return_value .= '     <h2 class="hw-post-link"><a href="' . $this->get_new_permalink($mainpage, $paged, $post_index, $post->link) . '" style="font-family:' . $font . ';' . $title_color . '">' . $post->title . '</a></h2>';
						if ($post_date == "Yes") {	$return_value .= '     <div class="hw-post-date" style="font-family:' . $font . ';">' . $post->date . '</div>'; }
						if ($thumbnail > 0)	 	 {  $return_value .= '     <div class="hw-post-thumb">' . $post->thumbnail . '</div>'; }
						$return_value .= '     <div class="hw-post-content" style="font-family:' . $font . ';">' . $post->summary . '</div>';
					else : // only head lines
						if ($thumbnail > 0)	 	 {  $return_value .= '     <div class="hw-post-thumb">' . $post->thumbnail . '</div>'; }
						$return_value .= '     <h2 class="hw-post-link"><a href="' . $this->get_new_permalink($mainpage, $paged, $post_index, $post->link) . '" style="font-family:' . $font . ';' . $title_color . '">' . $post->title . '</a></h2>';
						if ($post_date == "Yes") {	$return_value .= '     <div class="hw-post-date" style="font-family:' . $font . ';">' . $post->date . '</div>'; }
					endif;
					$return_value .= '</div>';
					$return_value .= '<div class="hw-clear-both"></div>';
					$return_value .= '<hr />';
				endif;
			endforeach;

			if ($pagination == "Yes") :
				$prev = "Previous";
				$next = "Next";
				if ($language == "es") { $prev = "Anterior"; $next = "Siguiente"; }
				if ($paged > 1)	{	$return_value .= '<a class="button" href="' . $mainpage . '?pg=' . ($paged - 1) . '">&laquo; ' . $prev . '</a>';  }
				$return_value .= ' <a class="button" href="' . $mainpage . '?pg=' . ($paged + 1) . '">' . $next . ' &raquo;</a>'; 
			endif;
			
			$return_value .= '</div>';
			
		else : 
		
		// ******************* if we must display the content of a single post *********************************

			foreach($hispanicize_wire_feed->posts as $post) :
				$return_value .= '<div class="hw-post-single">';
				$return_value .= '<h1 class="hw-post-title" style="font-family:' . $font . ';">' . $post->title . '</h1>';
				$return_value .= '<div class="hw-post-date" style="font-family:' . $font . ';">' . $post->date . '</div>';
				$return_value .= '<div class="hw-post-content" style="font-family:' . $font . ';">' . $post->text . '</div>';
				$return_value .= '</div>';
				$return_value .= '<div class="hw-clear-both"></div>';
				$return_value .= '<hr />';
				break;
			endforeach;
		
		endif;		
		
		if ($viewmore == "Yes") :
			if ($language == "en")	$viewmore_text = "View More";
			else $viewmore_text = "Ver M&aacute;s";
			$return_value .= '<div class="hw-post-viewmore"><a href="' . $mainpage . '" style="font-family:' . $font . ';' . $title_color . '">' . $viewmore_text . '</a></div>';
		endif;

		if ($target != 'sidebar' && $link_post == '') {
		    $powered_by = '<div class="widget-powered-hma"><a href="https://www.hispanicmarketadvisors.com/plug-ins" target="_blank">' . $powered_by_title . '</a></div>';
			$return_value .= $powered_by;
		}		

		$return_value .= '</div>';
		return $return_value;
		
	}
	
	public function get_light_color() {
		return "#edf1f7";
	}
	
	public function get_dark_color() {
		return "#6d798c";
	}	

	public function get_hispanicize_title($title) {
		$hw_title = 'hispanicize-wire-news';
		if (!empty($_GET['l']))  { $hw_title = $_GET['l']; }
		$hw_title = str_ireplace('-', ' ', $hw_title);
		$hw_title = ucwords($hw_title);
		return $hw_title;
	}

	public function get_new_permalink($mainpage, $paged, $post_index, $post_link) {
		$new_permalink = str_ireplace($this->hispanicize_domain, '', rtrim($post_link, '/'));
		// return $mainpage . '?l=' . $new_permalink . '&pg=' . $paged . '&i=' . $post_index;
		return $mainpage . '?l=' . $new_permalink;
	}

    /**
     * Load frontend CSS.
     * @access  public
     * @since   1.0.0
     * @return void
     */
    public function enqueue_styles() {
        wp_register_style($this->_token . '-frontend', esc_url($this->assets_url) . 'css/frontend.css', array(), $this->_version);
        wp_enqueue_style($this->_token . '-frontend');
    } // End enqueue_styles()

    /**
     * Load frontend Javascript.
     * @access  public
     * @since   1.0.0
     * @return void
     */
    public function enqueue_scripts() {
        // wp_register_script($this->_token . '-frontend', esc_url($this->assets_url) . 'js/frontend' . $this->script_suffix . '.js', array('jquery'), $this->_version);
        // wp_enqueue_script($this->_token . '-frontend');
    } // End enqueue_scripts()

    /**
     * Load admin CSS.
     * @access  public
     * @since   1.0.0
     * @return void
     */
    public function admin_enqueue_styles($hook = '') {
        // wp_register_style($this->_token . '-admin', esc_url($this->assets_url) . 'css/admin.css', array(), $this->_version);
        // wp_enqueue_style($this->_token . '-admin');
    } // End admin_enqueue_styles()

    /**
     * Load admin Javascript.
     * @access  public
     * @since   1.0.0
     * @return void
     */
    public function admin_enqueue_scripts ( $hook = '' ) {
        // wp_register_script($this->_token . '-admin', esc_url($this->assets_url) . 'js/admin' . $this->script_suffix . '.js', array('jquery'), $this->_version);
        // wp_enqueue_script($this->_token . '-admin');
    } // End admin_enqueue_scripts()
	
    /**
     * Main Hispanicize_Wire_News Instance
     *
     * Ensures only one instance of Hispanicize_Wire_News is loaded or can be loaded.
     *
     * @since 1.0.0
     * @static
     * @see Hispanicize_Wire_News()
     * @return Main Hispanicize_Wire_News instance
     */
    public static function instance ($file = '', $version = '3.2.0') {
        if (is_null(self::$_instance)) {
            self::$_instance = new self($file, $version);
        }
        return self::$_instance;
    } // End instance()

    /**
     * Cloning is forbidden.
     *
     * @since 1.0.0
     */
    public function __clone() {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->_version);
    } // End __clone()

    /**
     * Unserializing instances of this class is forbidden.
     *
     * @since 1.0.0
     */
    public function __wakeup() {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->_version);
    } // End __wakeup()

    /**
     * Installation. Runs on activation.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function install() {
        $this->_log_version_number();
    } // End install()

    /**
     * Log the plugin version number.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    private function _log_version_number() {
        update_option($this->_token . '_version', $this->_version);
    }
}

require 'plugin-updates/plugin-update-checker.php';
$ExampleUpdateChecker = PucFactory::buildUpdateChecker(
	'https://www.hispanicizewire.com/placements/info.json',
	__FILE__,
    'hispanicize-wire-news'
);
/*
//Here's how you can add query arguments to the URL.
function addSecretKey($query){
	$query['secret'] = 'foo';
	return $query;
}
$ExampleUpdateChecker->addQueryArgFilter('addSecretKey');
*/
?>