<?php
if (!defined('ABSPATH')) exit;

define('HW_DOMAIN', 'https://www.hispanicizewire.com/');
define('HW_API_URL', HW_DOMAIN . 'placements/feed-api.php');
define('HW_CACHE_HOURS', 6);

class Hispanicize_Wire_Settings {

    /**
     * The single instance of Hispanicize_Wire_Settings.
     * @var     object
     * @access  private
     * @since   1.0.0
     */
    private static $_instance = null;
	
    /**
     * The main plugin object.
     * @var     object
     * @access  public
     * @since   1.0.0
     */
    public $parent = null;

    /**
     * Prefix for plugin settings.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $base = '';

    /**
     * Available settings for plugin.
     * @var     array
     * @access  public
     * @since   1.0.0
     */
    public $settings = array();
	
    public function __construct ( $parent ) {
        $this->parent = $parent;

        $this->base = 'wpt_';
		
        // Initialise settings
        add_action('admin_init', array($this, 'init_settings'));

        // Register plugin settings
        add_action('admin_init' , array($this, 'register_settings'));

        // Add settings page to menu
        add_action('admin_menu' , array($this, 'add_menu_item'));

        // Add settings link to plugins page
        add_filter('plugin_action_links_' . plugin_basename($this->parent->file) , array($this, 'add_settings_link'));

        // add_action('admin_notices', array($this, 'admin_notices'));
    }

    /**
     * Initialise settings
     * @return void
     */
    public function init_settings() {
        $this->settings = $this->settings_fields();
    }

    /**
     * Add settings page to admin menu
     * @return void
     */
    public function add_menu_item() {
        add_options_page(__( 'Hispanicize Wire', 'hispanicize-wire-news' ), __( 'Hispanicize Wire', 'hispanicize-wire-news'), 'manage_options', 'hispanicize_wire_news_settings',  array($this, 'settings_page'));
		// add_options_page( 'Hispanicize Wire Options', 'Hispanicize Wire News', 'manage_options', 'hispanicize-wire-options', 'hispanicize_wire_options' );
    }


    /**
     * Add settings link to plugin list table
     * @param  array $links Existing links
     * @return array        Modified links
     */
    public function add_settings_link($links) {
        $settings_link = '<a href="options-general.php?page=hispanicize_wire_news_settings">' . __( 'Settings', 'hispanicize-wire-news' ) . '</a>';
        array_push($links, $settings_link);
        return $links;
    }

    /**
     * Build settings fields
     * @return array Fields to be displayed on settings page
     */
    private function settings_fields() {

        $settings['features'] = array(
            'title'                 => __('Instructions', 'hispanicize-wire-news'),
            'description'           =>  'Follow these instructions about how to generate a custom shortcode to be inserted in any widget or page:<br/>' .
										'<ol><li>In this link <a href="http://www.hispanicizewire.com/placements" target="_blank">http://www.hispanicizewire.com/placements</a> you can generate the shortcode.<br/><br/></li>' .
										'    <li>For <strong>widget</strong>, we highly recommend to select these options: <br/><br/>' . 
										'		  <ul>' . 
										'             <li><strong>Thumbnail Image Size: </strong> Thumbnail</li>' . 
										'             <li><strong>Link where you will display each entire post: </strong> It is the page of this website where you will list all post entries and each post entry.</li>' . 
										'             <li><strong>Number of Posts: </strong> Value between 3 and 5</li>' . 
										'             <li><strong>View More option:</strong> Yes</li>' .
										'             <li><strong>Pagination option:</strong> No</li>' . 
										'         </ul><br/></li>' .
										'<p>Example: <div style="color:#f00;font-weight:bold;">[hispanicize-wire-news logo="Yes" title="Hispanicize Wire News" thumbnail="64" num_posts="3" post_date="Yes" author="No" color="Light" font="Arial" fontsize="11" width="100" mainpage="http://www.yourdomain.com/hispanicize-wire-news" viewmore="Yes" pagination="No"]</div></p>' . 
										'     <li>For <strong>list of post entries</strong>, we highly recommend to select these options: <br/><br/>' .
										'		  <ul>' . 
										'		      <li><strong>Do you want to add the Hispanicize Wire logo? </strong> No</li>' . 
										'		      <li><strong>Personalize the Title (Hispanicize Wire News by default): </strong> (empty)</li>' . 
										'             <li><strong>Thumbnail Image Size: </strong> Large</li>' . 
										'             <li><strong>Link where you will display each entire post: </strong> It is the page of this website where you will list all post entries and each post entry.</li>' . 
										'		      <li><strong>Number of Posts: </strong> 10</li>' . 
										'             <li><strong>View More option:</strong> No</li>' .
										'             <li><strong>Pagination option:</strong> Yes</li>' . 
										'         </ul></li>' .
										'<p>Example: <div style="color:#f00;font-weight:bold;">[hispanicize-wire-news logo="No" title="" thumbnail="150" num_posts="10" post_date="Yes" author="No" color="Light" font="Arial" fontsize="11" width="100" mainpage="http://www.yourdomain.com/hispanicize-wire-news" viewmore="No" pagination="Yes"]</div></p>' . 
										'</ol>',
			'fields'                => array()
        );

        $settings = apply_filters('hispanicize_wire_news_settings_fields', $settings);

        return $settings;
    }

    /**
     * Register plugin settings
     * @return void
     */
    public function register_settings() {
        if (is_array($this->settings)) {
            foreach($this->settings as $section => $data) {

                // Add section to page
                add_settings_section($section, $data['title'], array($this, 'settings_section'), 'hispanicize_wire_news_settings');

                foreach( $data['fields'] as $field ) {

                    // Validation callback for field
                    $validation = '';
                    if( isset($field['callback'])) {
                        $validation = $field['callback'];
                    }

                    // Register field
                    $option_name = $this->base . $field['id'];
                    register_setting('hispanicize_wire_news_settings', $option_name, $validation);

                    // Add field to page
                    add_settings_field($field['id'], $field['label'], array($this, 'display_field'), 'hispanicize_wire_news_settings', $section, array('field' => $field));
                }
            }
        }
    }

    public function settings_section($section) {
        $html = '<p> ' . $this->settings[ $section['id'] ]['description'] . '</p>' . "\n";
        echo $html;
    }

    /**
     * Generate HTML for displaying fields
     * @param  array $args Field data
     * @return void
     */
    public function display_field($args) {

        $field = $args['field'];

        $html = '';

        $option_name = $this->base . $field['id'];
        $option = get_option($option_name);

        $data = '';
        if (isset($field['default'])) {
            $data = $field['default'];
            if ($option) {
                $data = $option;
            }
        }

        switch( $field['type'] ) {

            case 'text':
            case 'password':
            case 'number':
                $html .= '<input id="' . esc_attr( $field['id'] ) . '" type="' . $field['type'] . '" name="' . esc_attr( $option_name ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" class="regular-text" value="' . $data . '"/>' . "\n";
            break;
            case 'hidden':
                $html .= $data . '<input id="' . esc_attr( $field['id'] ) . '" type="' . $field['type'] . '" name="' . esc_attr( $option_name ) . '" value="' . $data . '"/>' . "\n";
            break;
            case 'text_secret':
                $html .= '<input id="' . esc_attr( $field['id'] ) . '" type="text" name="' . esc_attr( $option_name ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" value=""/>' . "\n";
            break;

            case 'textarea':
                $html .= '<textarea id="' . esc_attr( $field['id'] ) . '" rows="5" cols="50" name="' . esc_attr( $option_name ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '">' . $data . '</textarea><br/>'. "\n";
            break;

            case 'checkbox':
                $checked = '';
                if( $option && 'on' == $option ){
                    $checked = 'checked="checked"';
                }
                $html .= '<input id="' . esc_attr( $field['id'] ) . '" type="' . $field['type'] . '" name="' . esc_attr( $option_name ) . '" ' . $checked . '/>' . "\n";
            break;

            case 'checkbox_multi':
                foreach( $field['options'] as $k => $v ) {
                    $checked = false;
                    if( in_array( $k, $data ) ) {
                        $checked = true;
                    }
                    $html .= '<label for="' . esc_attr( $field['id'] . '_' . $k ) . '"><input type="checkbox" ' . checked( $checked, true, false ) . ' name="' . esc_attr( $option_name ) . '[]" value="' . esc_attr( $k ) . '" id="' . esc_attr( $field['id'] . '_' . $k ) . '" /> ' . $v . '</label> ';
                }
            break;

            case 'radio':
                foreach( $field['options'] as $k => $v ) {
                    $checked = false;
                    if( $k == $data ) {
                        $checked = true;
                    }
                    $html .= '<label for="' . esc_attr( $field['id'] . '_' . $k ) . '"><input type="radio" ' . checked( $checked, true, false ) . ' name="' . esc_attr( $option_name ) . '" value="' . esc_attr( $k ) . '" id="' . esc_attr( $field['id'] . '_' . $k ) . '" /> ' . $v . '</label> ';
                }
            break;

            case 'select':
                $html .= '<select name="' . esc_attr( $option_name ) . '" id="' . esc_attr( $field['id'] ) . '">';
                foreach( $field['options'] as $k => $v ) {
                    $selected = false;
                    if( $k == $data ) {
                        $selected = true;
                    }
                    $html .= '<option ' . selected( $selected, true, false ) . ' value="' . esc_attr( $k ) . '">' . $v . '</option>';
                }
                $html .= '</select> ';
            break;

            case 'select_multi':
                $html .= '<select name="' . esc_attr( $option_name ) . '[]" id="' . esc_attr( $field['id'] ) . '" multiple="multiple">';
                foreach( $field['options'] as $k => $v ) {
                    $selected = false;
                    if( in_array( $k, $data ) ) {
                        $selected = true;
                    }
                    $html .= '<option ' . selected( $selected, true, false ) . ' value="' . esc_attr( $k ) . '" />' . $v . '</label> ';
                }
                $html .= '</select> ';
            break;

            case 'image':
                $image_thumb = '';
                if( $data ) {
                    $image_thumb = wp_get_attachment_thumb_url( $data );
                }
                $html .= '<img id="' . $option_name . '_preview" class="image_preview" src="' . $image_thumb . '" /><br/>' . "\n";
                $html .= '<input id="' . $option_name . '_button" type="button" data-uploader_title="' . __( 'Upload an image' , 'hispanicize-wire-news' ) . '" data-uploader_button_text="' . __( 'Use image' , 'hispanicize-wire-news' ) . '" class="image_upload_button button" value="'. __( 'Upload new image' , 'hispanicize-wire-news' ) . '" />' . "\n";
                $html .= '<input id="' . $option_name . '_delete" type="button" class="image_delete_button button" value="'. __( 'Remove image' , 'hispanicize-wire-news' ) . '" />' . "\n";
                $html .= '<input id="' . $option_name . '" class="image_data_field" type="hidden" name="' . $option_name . '" value="' . $data . '"/><br/>' . "\n";
            break;

        }

        switch( $field['type'] ) {

            case 'checkbox_multi':
            case 'radio':
            case 'select_multi':
                $html .= '<br/><span class="description">' . $field['description'] . '</span>';
            break;

            default:
                $html .= '<label for="' . esc_attr( $field['id'] ) . '"><span class="description">' . $field['description'] . '</span></label>' . "\n";
            break;
        }

        echo $html;
    }

    /**
     * Validate individual settings field
     * @param  string $data Inputted value
     * @return string       Validated value
     */
    public function validate_field($data) {
        if ($data && strlen($data) > 0 && $data != '') {
            $data = urlencode(strtolower(str_replace(' ', '-', $data)));
        }
        return $data;
    }
	
    /**
     * Load settings page content
     * @return void
     */
    public function settings_page() {

		$html_code = "";
	
        // Build page HTML
		$html = '<div class="wrap" id="hispanicize_wire_news_settings">' . "\n";
		$html .= '<h2>' . __( 'Plugin Settings' , 'hispanicize-wire-news' ) . '</h2>' . "\n";
		$html .= '<form method="post" action="" enctype="multipart/form-data">' . "\n";

		// Setup navigation
		$html .= '<ul id="settings-sections" class="subsubsub hide-if-no-js">' . "\n";
		$html .= '<li><a class="tab all current" href="#all">' . __( 'All' , 'hispanicize-wire-news' ) . '</a></li>' . "\n";

		foreach( $this->settings as $section => $data ) {
			$html .= '<li>| <a class="tab" href="#' . $section . '">' . $data['title'] . '</a></li>' . "\n";
		}

		$html .= '</ul>' . "\n";

		$html .= '<div class="clear"></div>' . "\n";

		// Get settings fields
		ob_start();
		settings_fields( 'hispanicize_wire_news_settings' );
		do_settings_sections( 'hispanicize_wire_news_settings' );
		$html .= ob_get_clean();

		$html .= '<p class="submit">' . "\n";
		// $html .= '<input name="Submit" type="submit" class="button-primary" value="' . esc_attr( __( 'Save Settings' , 'hispanicize-wire-news' ) ) . '" /> <input type="button" data-url="options-general.php?page=hispanicize_wire_news_settings" class="button-secondary reset" value="Reset">' . "\n";
		$html .= '<input name="Submit" type="submit" class="button-primary" value="' . esc_attr( __( 'OK' , 'hispanicize-wire-news' ) ) . '" /> ' . "\n";
		$html .= '</p>' . "\n";
		$html .= '</form>' . "\n";
		$html .= '</div>' . "\n";
		$html .= '<div style="font-family:Arial;font-size:11px;line-height:12px;">' . $html_code . '</div>' . "\n";

		echo $html;
    }	
	
	
    /**
     * Main Hispanicize_Wire_Settings Instance
     *
     * Ensures only one instance of Hispanicize_Wire_Settings is loaded or can be loaded.
     *
     * @since 1.0.0
     * @static
     * @see Hispanicize_Wire_News_Plugin()
     * @return Main Hispanicize_Wire_Settings instance
     */
    public static function instance($parent) {
        if (is_null(self::$_instance)) {
            self::$_instance = new self($parent);
        }
        return self::$_instance;
    } // End instance()
	
    /**
     * Cloning is forbidden.
     *
     * @since 1.0.0
     */
    public function __clone() {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->parent->_version);
    } // End __clone()

    /**
     * Unserializing instances of this class is forbidden.
     *
     * @since 1.0.0
     */
    public function __wakeup() {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->parent->_version);
    } // End __wakeup()

}
